==> cspace-ui-0.2.0.tgz: package/src/components/record/RecordEditor.jsx <==
import React, { Component, PropTypes } from 'react';
import Immutable from 'immutable';
import { FormattedMessage } from 'react-intl';
import { components as inputComponents } from 'cspace-input';
import { DOCUMENT_PROPERTY_NAME } from '../../helpers/recordDataHelpers';
import styles from '../../../styles/cspace-ui/RecordEditor.css';

const { Label } = inputComponents;

function getMessage(Wrapper, component, messageDescriptors) {
  const {
    msgkey,
    name,
  } = component.props;

  const key = msgkey || name;
  const messageDescriptor = messageDescriptors[key];

  if (!messageDescriptor) {
    return null;
  }

  return (
    <Wrapper>
      <FormattedMessage {...messageDescriptor} />
    </Wrapper>
  );
}

function renderTemplate(component, messageDescriptors, handlers) {
  const overrideProps = {};
  const type = component.type;

  if (type) {
    const propTypes = type.propTypes;

    if (propTypes) {
      if (propTypes.name) {
        if (propTypes.label && !component.props.label) {
          overrideProps.label = getMessage(Label, component, messageDescriptors);
        }

        if (propTypes.header && !component.props.header) {
          overrideProps.header = getMessage('h3', component, messageDescriptors);
        }
      }

      Object.keys(handlers).forEach((handlerName) => {
        if (propTypes[handlerName] && !component.props[handlerName]) {
          overrideProps[handlerName] = handlers[handlerName];
        }
      });
    }
  }

  return React.cloneElement(
    component,
    overrideProps,
    React.Children.map(
      component.props.children,
      child => renderTemplate(child, messageDescriptors, handlers)));
}

export default class RecordEditor extends Component {
  getChildContext() {
    return {
      recordType: this.props.recordType,
    };
  }

  render() {
    const {
      data,
      recordType,
      generateID,
      onAddInstance,
      onCommit,
      onMoveInstance,
      onRemoveInstance,
    } = this.props;

    const {
      config,
    } = this.context;

    const recordTypeConfig = config.recordTypes[recordType];

    const {
      forms,
      messageDescriptors,
    } = recordTypeConfig;

    const handlers = {
      generateID,
      onAddInstance,
      onCommit,
      onMoveInstance,
      onRemoveInstance,
    };

    const formTemplate = forms.default;

    const formContent = React.cloneElement(formTemplate, {
      name: DOCUMENT_PROPERTY_NAME,
      value: data.get(DOCUMENT_PROPERTY_NAME),
      children: React.Children.map(
        formTemplate.props.children,
        child => renderTemplate(child, messageDescriptors, handlers)),
    });

    return (
      <form
        autoComplete="off"
        className={styles.common}
      >
        {formContent}
      </form>
    );
  }
}

RecordEditor.propTypes = {
  recordType: PropTypes.string.isRequired,
  data: PropTypes.instanceOf(Immutable.Map),
  generateID: PropTypes.func,
  onAddInstance: PropTypes.func,
  onCommit: PropTypes.func,
  onMoveInstance: PropTypes.func,
  onRemoveInstance: PropTypes.func,
};

RecordEditor.defaultProps = {
  data: Immutable.Map(),
};

RecordEditor.childContextTypes = {
  recordType: PropTypes.string,
};

RecordEditor.contextTypes = {
  config: PropTypes.object,
};

==> cspace-ui-0.3.1.tgz: package/src/components/record/RecordEditor.jsx <==
import React, { Component, PropTypes } from 'react';
import Immutable from 'immutable';
import { FormattedMessage } from 'react-intl';
import { components as inputComponents } from 'cspace-input';
import { DOCUMENT_PROPERTY_NAME } from '../../helpers/recordDataHelpers';
import styles from '../../../styles/cspace-ui/RecordEditor.css';

const { Label } = inputComponents;

function getLabel(component, messages) {
  const {
    msgkey,
    name,
  } = component.props;

  const key = msgkey || name;
  const message = messages.field[key];

  if (!message || message.hidden) {
    return null;
  }

  return (
    <Label>
      <FormattedMessage {...message} />
    </Label>
  );
}

function renderTemplate(component, messages, handlers) {
  const overrideProps = {};
  const type = component.type;

  if (type) {
    const propTypes = type.propTypes;

    if (propTypes) {
      if (propTypes.name) {
        if (propTypes.label && typeof component.props.label === 'undefined') {
          overrideProps.label = getLabel(component, messages);
        }
      }

      Object.keys(handlers).forEach((handlerName) => {
        if (propTypes[handlerName] && !component.props[handlerName]) {
          overrideProps[handlerName] = handlers[handlerName];
        }
      });
    }
  }

  return React.cloneElement(
    component,
    overrideProps,
    React.Children.map(
      component.props.children,
      child => renderTemplate(child, messages, handlers)));
}

const propTypes = {
  recordType: PropTypes.string.isRequired,
  csid: PropTypes.string,
  data: PropTypes.instanceOf(Immutable.Map),
  onAddInstance: PropTypes.func,
  onCommit: PropTypes.func,
  onMoveInstance: PropTypes.func,
  onRemoveInstance: PropTypes.func,
};

const defaultProps = {
  data: Immutable.Map(),
};

const childContextTypes = {
  recordType: PropTypes.string,
  csid: PropTypes.string,
};

const contextTypes = {
  config: PropTypes.object,
};

export default class RecordEditor extends Component {
  getChildContext() {
    const {
      csid,
      recordType,
    } = this.props;

    return {
      csid,
      recordType,
    };
  }

  render() {
    const {
      data,
      recordType,
      onAddInstance,
      onCommit,
      onMoveInstance,
      onRemoveInstance,
    } = this.props;

    const {
      config,
    } = this.context;

    const recordTypeConfig = config.recordTypes[recordType];

    if (!recordTypeConfig) {
      return null;
    }

    const {
      forms,
      messages,
    } = recordTypeConfig;

    const handlers = {
      onAddInstance,
      onCommit,
      onMoveInstance,
      onRemoveInstance,
    };

    const formTemplate = forms.default;

    const formContent = React.cloneElement(formTemplate, {
      name: DOCUMENT_PROPERTY_NAME,
      value: data.get(DOCUMENT_PROPERTY_NAME),
      children: React.Children.map(
        formTemplate.props.children,
        child => renderTemplate(child, messages, handlers)),
    });

    return (
      <form
        autoComplete="off"
        className={styles.common}
      >
        {formContent}
      </form>
    );
  }
}

RecordEditor.propTypes = propTypes;
RecordEditor.defaultProps = defaultProps;
RecordEditor.childContextTypes = childContextTypes;
RecordEditor.contextTypes = contextTypes;
